@@ -1,5 +1,8 @@
 package Egg::Appli::note;
 use strict;
+use warnings;
+
+our $VERSION= '0.01';
 
 1;
 
