@@ -6,9 +6,12 @@ package Egg::Const;
 # $Id$
 #
 use strict;
+use warnings;
 use base qw/Exporter/;
 no warnings 'redefine';
 
+our $VERSION= '0.02';
+
 our @EXPORT=
   qw/OK AUTH_REQUIRED FORBIDDEN NOT_FOUND SERVER_ERROR TRUE FALSE/;
 
